@@ -23,6 +23,7 @@ class EmptySearch(object):
         self.aggs = AggsProxy('')
         self._highlight = {}
         self._sort = []
+        self.total = None
 
     def __len__(self):
         return 0
@@ -30,12 +31,19 @@ class EmptySearch(object):
     def __iter__(self):
         return iter([])
 
+    def __getitem__(self, *args, **kwargs):
+        return self
+
     def highlight(self, *args, **kwargs):
         return self
 
     def sort(self, *args, **kwargs):
         return self
 
+    @property
+    def hits(self):
+        return self
+
     def execute(self, *args, **kwargs):
         return self
 
@@ -51,7 +59,7 @@ class DictionaryProxy(object):
 
     def __getattr__(self, item):
         val = self.__mapping.get(item, None)
-        if isinstance(val, datetime.datetime):
+        if isinstance(val, datetime.datetime) and not val.tzinfo:
             val = val.date()
         return val
 
